#
# spec file for package python-python-jsonschema-objects
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-jsonschema-objects
Version:        0.5.4
Release:        1.1
Summary:        An object wrapper for JSON Schema definitions
License:        MIT
URL:            https://python-jsonschema-objects.readthedocs.org/
Source:         https://files.pythonhosted.org/packages/source/p/python_jsonschema_objects/python_jsonschema_objects-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/cwacek/python-jsonschema-objects/pull/289 clear some Python 2 remnants (including six)
Patch:          no-six.patch
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Markdown >= 2.4
Requires:       python-inflection >= 0.2
Requires:       python-jsonschema >= 4.18
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Markdown >= 2.4}
BuildRequires:  %{python_module inflection >= 0.2}
BuildRequires:  %{python_module jsonschema >= 4.18}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
An object wrapper for JSON Schema definitions

%prep
%autosetup -p1 -n python_jsonschema_objects-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%{python_expand rm -r %{buildroot}%{$python_sitelib}/python_jsonschema_objects/examples/
%fdupes %{buildroot}%{$python_sitelib}
}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/python_jsonschema_objects
%{python_sitelib}/python_jsonschema_objects-%{version}.dist-info

%changelog
* Thu Jun  6 2024 Markéta Machová <mmachova@suse.com>
- Update to 0.5.4
  * bugfix: Update the way specifications are retrieved
  * tests: Add tests to validate expected behavior on some issues
  * handle nested anyof, ensure that data gets passed down via object creators
  * feature: Add support for the const keyword
- Add no-six.patch to get rid of six
- Drop no-longer-needed use-specification-obj.patch
* Mon Dec 11 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.5.1:
  * Setup for handling anyOf simplifying to oneOf on import.
- Add patch use-specification-obj.patch:
  * Stop passing string schemas, convert it to a Specification object
* Wed Sep 20 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.5.0:
  * Migrate to jsonschema 4.18
  * Drop support for Python 3.7 due to lack of support under jsonschema>=4.18
  * Drop support for jsonschema<4.18 due to breaking changes in that
    libraries interfaces
- Migrate to pyproject macros
- Stop using greedy globs in %%files
* Tue Jul 11 2023 Markéta Machová <mmachova@suse.com>
- Update to 0.4.2
  * Handle removed markdown version_info
  * fix nested oneOf resolution with different schema types
- Drop merged pso-markdown-version.patch
- Pin jsonschema version to < 4.18, not supported yet
* Fri Aug 26 2022 Ben Greiner <code@bnavigator.de>
- Add pso-markdown-version.patch
  * gh#cwacek/python-jsonschema-objects#230
* Fri Jul  8 2022 Steve Kowalik <steven.kowalik@suse.com>
- Skip a failing test for now.
* Fri Jan 21 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.1:
  * This release just incorporates the fix for #223
  * Default values will now always serialize, even if the default value is null. Since this change could cause unexpected changes in serialized output the minor version has been bumped. Fixes #200
  * Literals now properly support comparisons of all types (#213)
  * oneOfs inside oneOfs (oneOf-ception?!) no longer fail to serialize (#214)
  * #203 validatorSchemas passed in are now respected
  * #208 oneOf roundtrip serializations work better
  * #207 Another fix for abc deprecation
  * Fixes import path for collections.abc to be compliant with Python 3.8 [#197] (h/t @adriangay)
- Remove duplicate setuptools BuildRequires.
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 0.3.12
  * Going forward, this library will no longer test on or support Python 2.7 because it's EOL
  * Fixes formatting of supported schema versions (#184)
  * Removes some confusing code related to ArrayWrapper initialization (#188)
  * ProtocolBase objects (most objects) now support deepcopy. (#185)
* Tue Sep 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Mon Sep 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.3.11
